#!/usr/bin/env python

"""
A default theme for HTML output.

Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.themes.common import Theme

class DefaultHTMLTheme(Theme):

    "A default theme."

    name = "html"
    origin = __file__

    def apply(self, text):

        "Apply this theme to the given 'text', returning a themed version."

        template = self.load_resource("template.html")
        subs = {
            "encoding" : self.output.encoding,
            "root" : self.linker.get_top_level() or ".",
            "text" : text,
            "title" : self.metadata.get("pagename"),
            }
        return template % subs

    def install_resources(self):

        "Install resources for this theme."

        self.install_resource("css", "_css")

theme = DefaultHTMLTheme

# vim: tabstop=4 expandtab shiftwidth=4
